@@ -573,6 +573,28 @@ QVariant ComicProviderWrapper::nextIdentifierVariant() const
         case StringIdentifier:
             break;
         }
+    //check if the nextIdentifier is correct
+    } else if ( !mNextIdentifier.isNull() ) {
+        //no nextIdentifier if mIdentifier == mLastIdentifier or if no identifier has been specified
+        switch ( identifierType() ) {
+        case DateIdentifier:
+            if ( ( !mLastIdentifier.isNull() && ( mIdentifier.toDate() == mLastIdentifier.toDate() ) ) ||
+                 !mIdentifierSpecified ) {
+                return false;
+            }
+            break;
+        case NumberIdentifier:
+            if ( ( !mLastIdentifier.isNull() && ( mIdentifier.toInt() == mLastIdentifier.toInt() ) ) ||
+                 !mIdentifierSpecified ) {
+                return false;
+            }
+            break;
+        case StringIdentifier:
+            if ( !mIdentifierSpecified ) {
+                return false;
+            }
+            break;
+        }
     }
     return mNextIdentifier;
 }
@@ -598,6 +620,22 @@ QVariant ComicProviderWrapper::previousIdentifierVariant() const
         case StringIdentifier:
             break;
         }
+    } else if ( !mPreviousIdentifier.isNull() ) {
+        //no previousIdentifier if mIdentifier == mFirstIdentifier
+        switch ( identifierType() ) {
+        case DateIdentifier:
+            if ( !mFirstIdentifier.isNull() && ( mIdentifier.toDate() == mFirstIdentifier.toDate() ) ) {
+                return false;
+            }
+            break;
+        case NumberIdentifier:
+            if ( !mFirstIdentifier.isNull() && ( mIdentifier.toInt() == mFirstIdentifier.toInt() ) ) {
+                return false;
+            }
+            break;
+        case StringIdentifier:
+            break;
+        }
     }
     return mPreviousIdentifier;
 }
